<?php

namespace Drupal\twig_ui;

use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
use Drupal\Core\Entity\EntityInterface;

/**
 * Provides a listing of Twig templates.
 */
class TwigTemplateListBuilder extends ConfigEntityListBuilder {

  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $header['label'] = $this->t('Template');
    $header['id'] = $this->t('Machine name');
    $header['theme_suggestion'] = $this->t('Theme Suggestion');
    $header['themes'] = $this->t('Themes');
    $header['status'] = $this->t('Status');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    $row['label'] = $entity->label();
    $row['id'] = $entity->id();
    $row['theme_suggestion'] = $entity->get('theme_suggestion');

    $themes = $entity->get('themes');
    $row['themes'] = implode(', ', $themes);
    $row['status'] = ($entity->get('status')) ? 'Enabled' : 'Disabled';
    return $row + parent::buildRow($entity);
  }

  /**
   * {@inheritdoc}
   */
  public function getDefaultOperations(EntityInterface $entity) {
    $operations = parent::getDefaultOperations($entity);
    $operations['edit'] = [
      'title' => $this->t('Edit'),
      'weight' => 15,
      'url' => $entity->toUrl('edit-form'),
    ];
    $operations['delete'] = [
      'title' => $this->t('Delete'),
      'weight' => 15,
      'url' => $entity->toUrl('delete-form'),
    ];

    return $operations;
  }

}
